## 国债收益率曲线利率（日频）

接口：us_tycr

描述：获取美国每日国债收益率曲线利率

限量：单次最大可获取2000条数据

权限：用户积累120积分可以使用，积分越高频次越高。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 （YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| fields | str | N | 指定输出字段（e.g. fields='m1,y1'） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| m1 | float | Y | 1月期 |
| m2 | float | Y | 2月期 |
| m3 | float | Y | 3月期 |
| m4 | float | Y | 4月期（数据从20221019开始） |
| m6 | float | Y | 6月期 |
| y1 | float | Y | 1年期 |
| y2 | float | Y | 2年期 |
| y3 | float | Y | 3年期 |
| y5 | float | Y | 5年期 |
| y7 | float | Y | 7年期 |
| y10 | float | Y | 10年期 |
| y20 | float | Y | 20年期 |
| y30 | float | Y | 30年期 |

接口调用

```python
pro = ts.pro_api()

df = pro.us_tycr(start_date='20180101', end_date='20200327')


#获取1月期和1年期数据
df = pro.us_tycr(start_date='20180101', end_date='20200327', fields='m1,y1')
```

数据样例

```python
date    m1    m2    m3    m6    y1    y2    y3    y5    y7   y10   y20   y30
0     20200327  0.01  0.03  0.03  0.02  0.11  0.25  0.30  0.41  0.60  0.72  1.09  1.29
```